@@ -256,7 +256,7 @@ out:
 
 void bpf_print_ops(FILE *f, struct rtattr *bpf_ops, __u16 len)
 {
-	struct sock_filter *ops = (struct sock_filter *) RTA_DATA(bpf_ops);
+	struct sock_filter *ops = RTA_DATA(bpf_ops);
 	int i;
 
 	if (len == 0)
@@ -596,7 +596,7 @@ static const char *bpf_get_work_dir(enum bpf_prog_type type)
 	if (bpf_mnt_cached) {
 		const char *out = mnt;
 
-		if (out) {
+		if (out && type) {
 			snprintf(bpf_tmp, sizeof(bpf_tmp), "%s%s/",
 				 out, bpf_prog_to_subdir(type));
 			out = bpf_tmp;
